%{?mingw_package_header}

Name:           mingw-glib2
Version:        2.78.1
Release:        %mkrel 1
Summary:        MinGW Windows GLib2 library

License:        LGPLv2+
Group:          Development/Other
URL:            https://www.gtk.org/
# first two digits of version
%global release_version %(echo %{version} | awk -F. '{print $1"."$2}')
Source0:        https://download.gnome.org/sources/glib/%{release_version}/glib-%{version}.tar.xz

BuildArch:      noarch

BuildRequires:  meson
BuildRequires:  gcc
BuildRequires:  gcc-c++

BuildRequires:  mingw32-filesystem >= 107
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-win-iconv
BuildRequires:  mingw32-gettext
BuildRequires:  mingw32-libffi
BuildRequires:  mingw32-pcre2
BuildRequires:  mingw32-zlib

BuildRequires:  mingw64-filesystem >= 107
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-win-iconv
BuildRequires:  mingw64-gettext
BuildRequires:  mingw64-libffi
BuildRequires:  mingw64-pcre2
BuildRequires:  mingw64-zlib

# Native version required for msgfmt use in build
BuildRequires:  gettext
# Native version required for glib-genmarshal
BuildRequires:  pkgconfig(glib-2.0) >= 2.45.3
BuildRequires:  pkgconfig(python3)

# https://bugzilla.gnome.org/show_bug.cgi?id=674214
Patch1:         0001-Use-CreateFile-on-Win32-to-make-sure-g_unlink-always.patch

# Prefer the use of GCC constructors over DllMain
# This prevents having to depend on DllMain in static libraries
# https://lists.fedoraproject.org/pipermail/mingw/2013-March/006429.html
# https://lists.fedoraproject.org/pipermail/mingw/2013-March/006469.html
# https://bugzilla.gnome.org/show_bug.cgi?id=698118
#Patch5:         glib-prefer-constructors-over-DllMain.patch

%description
MinGW Windows Glib2 library.

# Win32
%package -n mingw32-glib2
Summary:        MinGW Windows Glib2 library for the win32 target
Group:          Development/Other
# glib-genmarshal and glib-mkenums are written in Python
Requires:       python3

%description -n mingw32-glib2
MinGW Windows Glib2 library.

%package -n mingw32-glib2-static
Summary:        Static version of the MinGW Windows GLib2 library
Group:          Development/Other
Requires:       mingw32-glib2 = %{version}-%{release}
Requires:       mingw32-gettext-static

%description -n mingw32-glib2-static
Static version of the MinGW Windows GLib2 library.

# Win64
%package -n mingw64-glib2
Summary:        MinGW Windows Glib2 library for the win64 target
Group:          Development/Other
# glib-genmarshal and glib-mkenums are written in Python
Requires:       python3

%description -n mingw64-glib2
MinGW Windows Glib2 library.

%package -n mingw64-glib2-static
Summary:        Static version of the MinGW Windows GLib2 library
Group:          Development/Other
Requires:       mingw64-glib2 = %{version}-%{release}
Requires:       mingw64-gettext-static

%description -n mingw64-glib2-static
Static version of the MinGW Windows GLib2 library.


%{?mingw_debug_package}


%prep
%autosetup -p1 -n glib-%{version}

%build
export MINGW_BUILDDIR_SUFFIX=static
%mingw_meson --default-library=static
%mingw_ninja
export MINGW_BUILDDIR_SUFFIX=shared
%mingw_meson --default-library=shared
%mingw_ninja

%install
export MINGW_BUILDDIR_SUFFIX=static
%mingw_ninja_install
export MINGW_BUILDDIR_SUFFIX=shared
%mingw_ninja_install

# There's a small difference in the file glibconfig.h between the
# shared and the static build:
#
#diff -ur shared/usr/i686-pc-mingw32/sys-root/mingw/lib/glib-2.0/include/glibconfig.h static/usr/i686-pc-mingw32/sys-root/mingw/lib/glib-2.0/include/glibconfig.h
#--- shared/usr/i686-pc-mingw32/sys-root/mingw/lib/glib-2.0/include/glibconfig.h	2009-02-20 17:34:35.735677022 +0100
#+++ static/usr/i686-pc-mingw32/sys-root/mingw/lib/glib-2.0/include/glibconfig.h	2009-02-20 17:33:35.498932269 +0100
#@@ -92,7 +92,8 @@
# 
# #define G_OS_WIN32
# #define G_PLATFORM_WIN32
#-
#+#define GLIB_STATIC_COMPILATION 1
#+#define GOBJECT_STATIC_COMPILATION 1
# 
# #define G_VA_COPY	va_copy
#
# However, we can't merge this change as it is situation-dependent...
#
# Developers using the static build of GLib need to add -DGLIB_STATIC_COMPILATION
# and -DGOBJECT_STATIC_COMPILATION to their CFLAGS to avoid compile failures

# Drop the folder which was temporary used for installing the static bits
rm -f %{buildroot}/%{mingw32_libdir}/charset.alias
rm -f %{buildroot}/%{mingw64_libdir}/charset.alias

# Drop the GDB helper files as we can't use the native Fedora GDB to debug Win32 programs
rm -rf %{buildroot}%{mingw32_datadir}/gdb
rm -rf %{buildroot}%{mingw64_datadir}/gdb

# Remove the gtk-doc documentation and manpages which duplicate Fedora native
rm -rf %{buildroot}%{mingw32_mandir}
rm -rf %{buildroot}%{mingw32_datadir}/gtk-doc

rm -rf %{buildroot}%{mingw64_mandir}
rm -rf %{buildroot}%{mingw64_datadir}/gtk-doc

# Bash-completion files aren't interesting for mingw
rm -rf %{buildroot}%{mingw32_datadir}/bash-completion
rm -rf %{buildroot}%{mingw64_datadir}/bash-completion

# The .def files are also of no use to other binaries
rm -f %{buildroot}%{mingw32_libdir}/*.def
rm -f %{buildroot}%{mingw64_libdir}/*.def

# The gdbus-codegen pieces are already in the native glib2 package
rm -f %{buildroot}%{mingw32_bindir}/gdbus-codegen
rm -rf %{buildroot}%{mingw32_libdir}/gdbus-2.0
sed -i 's|gdbus_codegen=.*|gdbus_codegen=%{_bindir}/gdbus-codegen|g' %{buildroot}%{mingw32_libdir}/pkgconfig/gio-2.0.pc

rm -f %{buildroot}%{mingw64_bindir}/gdbus-codegen
rm -rf %{buildroot}%{mingw64_libdir}/gdbus-2.0
sed -i 's|gdbus_codegen=.*|gdbus_codegen=%{_bindir}/gdbus-codegen|g' %{buildroot}%{mingw64_libdir}/pkgconfig/gio-2.0.pc

# Drop all .la files
find %{buildroot} -name "*.la" -delete

%mingw_find_lang glib20

# Manually invoke the python byte compile macro for each path that needs byte
# compilation.
%py_byte_compile %{__python3} %{buildroot}%{mingw32_datadir}/glib-2.0/gdb
%py_byte_compile %{__python3} %{buildroot}%{mingw32_datadir}/glib-2.0/codegen
%py_byte_compile %{__python3} %{buildroot}%{mingw64_datadir}/glib-2.0/gdb
%py_byte_compile %{__python3} %{buildroot}%{mingw64_datadir}/glib-2.0/codegen


# Win32
%files -n mingw32-glib2 -f mingw32-glib20.lang
%license COPYING
%{mingw32_bindir}/gdbus.exe
%{mingw32_bindir}/gio.exe
%{mingw32_bindir}/gio-querymodules.exe
%{mingw32_bindir}/glib-compile-resources.exe
%{mingw32_bindir}/glib-compile-schemas.exe
%{mingw32_bindir}/glib-genmarshal
%{mingw32_bindir}/glib-gettextize
%{mingw32_bindir}/glib-mkenums
%{mingw32_bindir}/gobject-query.exe
%{mingw32_bindir}/gresource.exe
%{mingw32_bindir}/gsettings.exe
%{mingw32_bindir}/gspawn-win32-helper-console.exe
%{mingw32_bindir}/gspawn-win32-helper.exe
%{mingw32_bindir}/gtester-report
%{mingw32_bindir}/libgio-2.0-0.dll
%{mingw32_bindir}/libglib-2.0-0.dll
%{mingw32_bindir}/libgmodule-2.0-0.dll
%{mingw32_bindir}/libgobject-2.0-0.dll
%{mingw32_bindir}/libgthread-2.0-0.dll
%{mingw32_includedir}/glib-2.0/
%{mingw32_includedir}/gio-win32-2.0/
%{mingw32_libdir}/glib-2.0/
%{mingw32_libdir}/libgio-2.0.dll.a
%{mingw32_libdir}/libglib-2.0.dll.a
%{mingw32_libdir}/libgmodule-2.0.dll.a
%{mingw32_libdir}/libgobject-2.0.dll.a
%{mingw32_libdir}/libgthread-2.0.dll.a
%{mingw32_libdir}/pkgconfig/gio-2.0.pc
%{mingw32_libdir}/pkgconfig/gio-windows-2.0.pc
%{mingw32_libdir}/pkgconfig/glib-2.0.pc
%{mingw32_libdir}/pkgconfig/gmodule-2.0.pc
%{mingw32_libdir}/pkgconfig/gmodule-export-2.0.pc
%{mingw32_libdir}/pkgconfig/gmodule-no-export-2.0.pc
%{mingw32_libdir}/pkgconfig/gobject-2.0.pc
%{mingw32_libdir}/pkgconfig/gthread-2.0.pc
%{mingw32_datadir}/aclocal/glib-2.0.m4
%{mingw32_datadir}/aclocal/glib-gettext.m4
%{mingw32_datadir}/aclocal/gsettings.m4
%{mingw32_datadir}/gettext/its/
%{mingw32_datadir}/glib-2.0/

%files -n mingw32-glib2-static
%{mingw32_libdir}/libgio-2.0.a
%{mingw32_libdir}/libglib-2.0.a
%{mingw32_libdir}/libgmodule-2.0.a
%{mingw32_libdir}/libgobject-2.0.a
%{mingw32_libdir}/libgthread-2.0.a

# Win64
%files -n mingw64-glib2 -f mingw64-glib20.lang
%license COPYING
%{mingw64_bindir}/gdbus.exe
%{mingw64_bindir}/gio.exe
%{mingw64_bindir}/gio-querymodules.exe
%{mingw64_bindir}/glib-compile-resources.exe
%{mingw64_bindir}/glib-compile-schemas.exe
%{mingw64_bindir}/glib-genmarshal
%{mingw64_bindir}/glib-gettextize
%{mingw64_bindir}/glib-mkenums
%{mingw64_bindir}/gobject-query.exe
%{mingw64_bindir}/gresource.exe
%{mingw64_bindir}/gsettings.exe
%{mingw64_bindir}/gspawn-win64-helper-console.exe
%{mingw64_bindir}/gspawn-win64-helper.exe
%{mingw64_bindir}/gtester-report
%{mingw64_bindir}/libgio-2.0-0.dll
%{mingw64_bindir}/libglib-2.0-0.dll
%{mingw64_bindir}/libgmodule-2.0-0.dll
%{mingw64_bindir}/libgobject-2.0-0.dll
%{mingw64_bindir}/libgthread-2.0-0.dll
%{mingw64_includedir}/glib-2.0/
%{mingw64_includedir}/gio-win32-2.0/
%{mingw64_libdir}/glib-2.0/
%{mingw64_libdir}/libgio-2.0.dll.a
%{mingw64_libdir}/libglib-2.0.dll.a
%{mingw64_libdir}/libgmodule-2.0.dll.a
%{mingw64_libdir}/libgobject-2.0.dll.a
%{mingw64_libdir}/libgthread-2.0.dll.a
%{mingw64_libdir}/pkgconfig/gio-2.0.pc
%{mingw64_libdir}/pkgconfig/gio-windows-2.0.pc
%{mingw64_libdir}/pkgconfig/glib-2.0.pc
%{mingw64_libdir}/pkgconfig/gmodule-2.0.pc
%{mingw64_libdir}/pkgconfig/gmodule-export-2.0.pc
%{mingw64_libdir}/pkgconfig/gmodule-no-export-2.0.pc
%{mingw64_libdir}/pkgconfig/gobject-2.0.pc
%{mingw64_libdir}/pkgconfig/gthread-2.0.pc
%{mingw64_datadir}/aclocal/glib-2.0.m4
%{mingw64_datadir}/aclocal/glib-gettext.m4
%{mingw64_datadir}/aclocal/gsettings.m4
%{mingw64_datadir}/gettext/its/
%{mingw64_datadir}/glib-2.0/

%files -n mingw64-glib2-static
%{mingw64_libdir}/libgio-2.0.a
%{mingw64_libdir}/libglib-2.0.a
%{mingw64_libdir}/libgmodule-2.0.a
%{mingw64_libdir}/libgobject-2.0.a
%{mingw64_libdir}/libgthread-2.0.a




%changelog
* Mon Nov 06 2023 tv <tv> 2.78.1-1.mga10
+ Revision: 2004941
- 2.78.1

* Wed Sep 27 2023 tv <tv> 2.78.0-1.mga10
+ Revision: 1991582
- Update to 2.78.0

* Sun Apr 16 2023 daviddavid <daviddavid> 2.74.1-4.mga9
+ Revision: 1953264
- remove no more needed old pcre-devel build dependency

* Tue Nov 22 2022 daviddavid <daviddavid> 2.74.1-3.mga9
+ Revision: 1909963
- rebuild for new mingw-libffi 3.4.4

* Tue Nov 15 2022 tv <tv> 2.74.1-2.mga9
+ Revision: 1907426
- Set gio-2.0.pc gdbus_codegen variable to system path.

* Tue Oct 25 2022 ovitters <ovitters> 2.74.1-1.mga9
+ Revision: 1899249
- new version 2.74.1

* Mon Sep 26 2022 tv <tv> 2.74.0-1.mga9
+ Revision: 1892360
- Update to 2.74.0

* Thu Jun 30 2022 ovitters <ovitters> 2.72.3-1.mga9
+ Revision: 1866795
- new version 2.72.3

* Mon May 30 2022 ovitters <ovitters> 2.72.2-1.mga9
+ Revision: 1860742
- new version 2.72.2

* Thu Apr 14 2022 ovitters <ovitters> 2.72.1-1.mga9
+ Revision: 1849353
- new version 2.72.1

* Wed Mar 30 2022 tv <tv> 2.72.0-1.mga9
+ Revision: 1834683
- Fix build: Manually invoke the python byte compile macro
- Update to 2.72.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ ovitters <ovitters>
- new version 2.68.4

* Thu Jun 10 2021 ovitters <ovitters> 2.68.3-1.mga9
+ Revision: 1730342
- new version 2.68.3

* Tue May 11 2021 ovitters <ovitters> 2.68.2-1.mga9
+ Revision: 1722481
- new version 2.68.2

* Thu Apr 08 2021 ovitters <ovitters> 2.68.1-1.mga9
+ Revision: 1714121
- new version 2.68.1

* Wed Mar 24 2021 ovitters <ovitters> 2.68.0-1.mga9
+ Revision: 1709150
- new version 2.68.0

* Thu Mar 18 2021 ovitters <ovitters> 2.66.8-1.mga9
+ Revision: 1704308
- new version 2.66.8

* Thu Feb 11 2021 ovitters <ovitters> 2.66.7-1.mga9
+ Revision: 1675157
- new version 2.66.7
- new version 2.66.6
- new version 2.66.5

* Thu Dec 17 2020 ovitters <ovitters> 2.66.4-1.mga8
+ Revision: 1659804
- new version 2.66.4

* Mon Nov 16 2020 ovitters <ovitters> 2.66.3-1.mga8
+ Revision: 1646626
- new version 2.66.3

* Mon Oct 19 2020 ovitters <ovitters> 2.66.2-1.mga8
+ Revision: 1637130
- new version 2.66.2

* Thu Oct 01 2020 ovitters <ovitters> 2.66.1-1.mga8
+ Revision: 1631469
- new version 2.66.1

* Sat Sep 26 2020 tv <tv> 2.66.0-2.mga8
+ Revision: 1630198
- rebuild for new mingw stack

* Sat Sep 12 2020 tv <tv> 2.66.0-1.mga8
+ Revision: 1624984
- 2.66.0

* Tue Aug 18 2020 ovitters <ovitters> 2.65.2-1.mga8
+ Revision: 1615007
- new version 2.65.2

* Fri Aug 07 2020 ovitters <ovitters> 2.65.1-1.mga8
+ Revision: 1611877
- new version 2.65.1

* Thu Jul 09 2020 ovitters <ovitters> 2.65.0-1.mga8
+ Revision: 1603446
- new version 2.65.0

* Thu Jul 02 2020 ovitters <ovitters> 2.64.4-1.mga8
+ Revision: 1601378
- new version 2.64.4

* Sat May 23 2020 ovitters <ovitters> 2.64.3-1.mga8
+ Revision: 1586926
- new version 2.64.3

* Thu Apr 09 2020 ovitters <ovitters> 2.64.2-1.mga8
+ Revision: 1565836
- new version 2.64.2

* Thu Mar 12 2020 daviddavid <daviddavid> 2.64.1-1.mga8
+ Revision: 1555667
- new version: 2.64.1

* Mon Feb 24 2020 ovitters <ovitters> 2.63.6-1.mga8
+ Revision: 1550070
- new version 2.63.6

* Wed Feb 19 2020 daviddavid <daviddavid> 2.63.5-1.mga8
+ Revision: 1543000
- new version: 2.63.5

* Tue Feb 18 2020 umeabot <umeabot> 2.62.5-2.mga8
+ Revision: 1541107
- Mageia 8 Mass Rebuild

* Tue Feb 18 2020 ovitters <ovitters> 2.62.5-1.mga8
+ Revision: 1540472
- new version 2.62.5
- dropped merged patch CVE-2020-6750.patch

* Thu Feb 13 2020 daviddavid <daviddavid> 2.62.4-2.mga8
+ Revision: 1513505
- backport proposed patch for CVE-2020-6750

* Thu Dec 19 2019 ovitters <ovitters> 2.62.4-1.mga8
+ Revision: 1469000
- new version 2.62.4

* Tue Nov 19 2019 ovitters <ovitters> 2.62.3-1.mga8
+ Revision: 1461748
- new version 2.62.3

* Mon Oct 21 2019 ovitters <ovitters> 2.62.2-1.mga8
+ Revision: 1455058
- new version 2.62.2

* Fri Oct 04 2019 ovitters <ovitters> 2.62.1-1.mga8
+ Revision: 1449277
- new version 2.62.1

* Thu Sep 05 2019 ovitters <ovitters> 2.62.0-1.mga8
+ Revision: 1437651
- new version 2.62.0

* Mon Sep 02 2019 ovitters <ovitters> 2.61.3-1.mga8
+ Revision: 1436272
- new version 2.61.3

* Wed Aug 28 2019 daviddavid <daviddavid> 2.61.2-1.mga8
+ Revision: 1434678
- new version: 2.61.2
- switch to meson build system

* Mon Jan 21 2019 ovitters <ovitters> 2.58.3-1.mga7
+ Revision: 1358675
- new version 2.58.3

* Tue Dec 18 2018 ovitters <ovitters> 2.58.2-1.mga7
+ Revision: 1342560
- new version 2.58.2

* Fri Sep 21 2018 daviddavid <daviddavid> 2.58.1-1.mga7
+ Revision: 1295475
- new version 2.58.1

* Thu Sep 20 2018 umeabot <umeabot> 2.57.2-2.mga7
+ Revision: 1279722
- Mageia 7 Mass Rebuild

* Fri Aug 17 2018 daviddavid <daviddavid> 2.57.2-1.mga7
+ Revision: 1252128
- new version: 2.57.2
+ ovitters <ovitters>
- new version 2.56.2
- dropped merged patch 00-fix-gdbus-codegen.patch

* Fri Jun 15 2018 daviddavid <daviddavid> 2.56.1-1.mga7
+ Revision: 1237064
- new version: 2.56.1

* Mon Jul 17 2017 ovitters <ovitters> 2.48.2-1.mga7
+ Revision: 1124645
- new version 2.48.2

* Tue May 10 2016 ovitters <ovitters> 2.48.1-1.mga6
+ Revision: 1011990
- new version 2.48.1

* Wed Apr 06 2016 tv <tv> 2.48.0-1.mga6
+ Revision: 998891
- new release

* Tue Apr 05 2016 tv <tv> 2.47.5-1.mga6
+ Revision: 998566
- BR mingwXX-pcre
- BR pcre-devel
- new release

* Tue Feb 02 2016 umeabot <umeabot> 2.38.2-4.mga6
+ Revision: 930915
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.38.2-3.mga5
+ Revision: 745277
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.38.2-2.mga5
+ Revision: 682440
- Mageia 5 Mass Rebuild

* Wed Feb 05 2014 ovitters <ovitters> 2.38.2-1.mga5
+ Revision: 582768
- new version 2.38.2

* Sat Oct 19 2013 umeabot <umeabot> 2.37.7-2.mga4
+ Revision: 536297
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 2.37.7-1.mga4
+ Revision: 483658
- imported package mingw-glib2

